@@ -30,8 +30,7 @@
 
 #include <gio/gio.h>
 #include <glib/gstdio.h>
-#include <telepathy-glib/interfaces.h>
-#include <telepathy-glib/util.h>
+#include <telepathy-glib/telepathy-glib.h>
 
 #include <telepathy-logger/conf-internal.h>
 #include <telepathy-logger/entity-internal.h>
@@ -305,7 +304,7 @@ tpl_log_manager_init (TplLogManager *self)
 
 
 /**
- * tpl_log_manager_dup_singleton
+ * tpl_log_manager_dup_singleton:
  *
  * Returns: (transfer full): a new reference on the log manager
  */
@@ -317,7 +316,7 @@ tpl_log_manager_dup_singleton (void)
 
 
 /*
- * _tpl_log_manager_add_event
+ * _tpl_log_manager_add_event:
  * @manager: the log manager
  * @event: a TplEvent subclass's instance
  * @error: the memory location of GError, filled if an error occurs
@@ -385,7 +384,7 @@ _tpl_log_manager_add_event (TplLogManager *manager,
 
 
 /*
- * _tpl_log_manager_register_log_store
+ * _tpl_log_manager_register_log_store:
  * @self: the log manager
  * @logstore: a TplLogStore interface implementation
  *
@@ -610,7 +609,7 @@ _tpl_log_manager_get_filtered_events (TplLogManager *manager,
 
 
 /*
- * _tpl_log_manager_get_entities
+ * _tpl_log_manager_get_entities:
  * @manager: the log manager
  * @account: a TpAccount the query will return data related to
  *
@@ -723,7 +722,7 @@ _tpl_log_manager_search_hit_free (TplLogSearchHit *hit)
 
 
 /**
- * tpl_log_manager_search_free: (skip):
+ * tpl_log_manager_search_free: (skip)
  * @hits: a #GList of #TplLogSearchHit
  *
  * Free @hits and its content.
@@ -990,7 +989,7 @@ _get_events_for_date_async_thread (GSimpleAsyncResult *simple,
 
 
 /**
- * tpl_log_manager_get_events_for_date_async
+ * tpl_log_manager_get_events_for_date_async:
  * @manager: a #TplLogManager
  * @account: a #TpAccount
  * @target: a non-NULL #TplEntity
@@ -1043,7 +1042,7 @@ tpl_log_manager_get_events_for_date_async (TplLogManager *manager,
 
 
 /**
- * tpl_log_manager_get_events_for_date_finish
+ * tpl_log_manager_get_events_for_date_finish:
  * @self: a #TplLogManager
  * @result: a #GAsyncResult
  * @events: (out) (transfer full) (element-type TelepathyLogger.Event): a
@@ -1106,9 +1105,10 @@ _get_filtered_events_async_thread (GSimpleAsyncResult *simple,
  * @target: a non-NULL #TplEntity
  * @type_mask: event type filter see #TplEventTypeMask
  * @num_events: number of maximum events to fetch
- * @filter: (scope async): an optional filter function
+ * @filter: (scope call) (allow-none): an optional filter function
  * @filter_user_data: user data to pass to @filter
- * @callback: (scope async): a callback to call when the request is satisfied
+ * @callback: (scope async) (allow-none): a callback to call when
+ * the request is satisfied
  * @user_data: data to pass to @callback
  *
  * Retrieve the most recent @num_event events exchanged with @target.
