@@ -1,4 +1,3 @@
-/*-*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * Copyright (C) 2008-2011 Collabora Ltd.
  *
@@ -24,7 +23,7 @@
 #define __TPL_LOG_STORE_H__
 
 #include <glib-object.h>
-#include <telepathy-glib/account.h>
+#include <telepathy-glib/telepathy-glib.h>
 
 #include <telepathy-logger/event.h>
 #include <telepathy-logger/log-manager.h>
