@@ -683,7 +683,7 @@ _tpl_log_store_sqlite_get_pending_messages (TplLogStore *self,
   int e;
 
   g_return_val_if_fail (TPL_IS_LOG_STORE_SQLITE (self), NULL);
-  g_return_val_if_fail (TPL_IS_CHANNEL (channel), NULL);
+  g_return_val_if_fail (TP_IS_CHANNEL (channel), NULL);
   g_return_val_if_fail (error == NULL || *error == NULL, NULL);
 
   DEBUG ("Listing pending messages for channel %s",
@@ -692,7 +692,7 @@ _tpl_log_store_sqlite_get_pending_messages (TplLogStore *self,
   e = sqlite3_prepare_v2 (priv->db, "SELECT id,timestamp "
       "FROM pending_messages "
       "WHERE channel=? "
-      "ORDER BY id DSC",
+      "ORDER BY id ASC",
       -1, &sql, NULL);
 
   if (e != SQLITE_OK)
@@ -784,6 +784,8 @@ _tpl_log_store_sqlite_remove_pending_messages (TplLogStore *self,
   g_string_append_printf (query, "channel='%s' AND id IN (%u",
       get_channel_name (channel), GPOINTER_TO_UINT (pending_ids->data));
 
+  DEBUG (" - pending_id: %u", GPOINTER_TO_UINT (pending_ids->data));
+
   for (it = g_list_next (pending_ids); it != NULL; it = g_list_next (it))
     {
       DEBUG (" - pending_id: %u", GPOINTER_TO_UINT (it->data));
