@@ -33,11 +33,8 @@
 #include <glib-object.h>
 #include <libxml/parser.h>
 #include <libxml/tree.h>
-#include <telepathy-glib/account.h>
-#include <telepathy-glib/account-manager.h>
-#include <telepathy-glib/dbus.h>
-#include <telepathy-glib/defs.h>
-#include <telepathy-glib/util.h>
+
+#include <telepathy-glib/telepathy-glib.h>
 
 #include "telepathy-logger/call-event.h"
 #include "telepathy-logger/call-event-internal.h"
@@ -923,6 +920,7 @@ log_store_xml_get_dates (TplLogStore *store,
 {
   TplLogStoreXml *self = (TplLogStoreXml *) store;
   GList *dates = NULL;
+  GList *l;
   gchar *directory = NULL;
   GDir *dir = NULL;
   GString *pattern = NULL;
@@ -975,6 +973,18 @@ log_store_xml_get_dates (TplLogStore *store,
       g_free (str);
     }
 
+  /* Filter out duplicate dates in-place */
+  for (l = dates; g_list_next (l) != NULL; l = g_list_next (l))
+    {
+      GList *next = g_list_next (l);
+
+      if (g_date_compare ((GDate *) next->data, (GDate *) l->data) == 0)
+        {
+          g_date_free ((GDate *) next->data);
+          l = g_list_delete_link (l, next);
+        }
+    }
+
 out:
   g_free (directory);
 
