@@ -22,20 +22,14 @@
 #include "observer-internal.h"
 
 #include <glib.h>
-#include <telepathy-glib/interfaces.h>
-#include <telepathy-glib/channel.h>
-#include <telepathy-glib/gtypes.h>
-#include <telepathy-glib/dbus.h>
-#include <telepathy-glib/svc-generic.h>
-#include <telepathy-glib/svc-client.h>
-#include <telepathy-glib/account-manager.h>
+#include <telepathy-glib/telepathy-glib.h>
+#include <telepathy-glib/telepathy-glib-dbus.h>
 
-#include <telepathy-logger/channel-internal.h>
-#include <telepathy-logger/channel-factory-internal.h>
 #include <telepathy-logger/log-manager.h>
 
 #define DEBUG_FLAG TPL_DEBUG_OBSERVER
 #include <telepathy-logger/action-chain-internal.h>
+#include <telepathy-logger/client-factory-internal.h>
 #include <telepathy-logger/debug-internal.h>
 #include <telepathy-logger/util-internal.h>
 
@@ -81,22 +75,16 @@
  */
 
 static void tpl_observer_dispose (GObject * obj);
-static void channel_prepared_cb (GObject *obj,
-    GAsyncResult *result,
-    gpointer user_data);
-static TplChannelFactory tpl_observer_get_channel_factory (TplObserver *self);
+static gboolean _tpl_observer_register_channel (TplObserver *self,
+    TpChannel *channel);
 
 struct _TplObserverPriv
 {
     /* Registered channels
      * channel path borrowed from the TplChannel => reffed TplChannel */
     GHashTable *channels;
-    /* Channels that we'll register once they are registered
-     * channel path borrowed from the TplChannel => reffed TplChannel */
-    GHashTable *preparing_channels;
     TplLogManager *logmanager;
     gboolean  dbus_registered;
-    TplChannelFactory channel_factory;
 };
 
 typedef struct
@@ -106,8 +94,6 @@ typedef struct
   TpObserveChannelsContext *ctx;
 } ObservingContext;
 
-static gboolean observing_context_try_to_return (ObservingContext *ctx);
-
 static TplObserver *observer_singleton = NULL;
 
 enum
@@ -128,94 +114,22 @@ tpl_observer_observe_channels (TpBaseClient *client,
     TpObserveChannelsContext *context)
 {
   TplObserver *self = TPL_OBSERVER (client);
-  TplChannelFactory chan_factory;
-  GError *error = NULL;
-  ObservingContext *observing_ctx = NULL;
-  const gchar *chan_type;
   GList *l;
 
-  chan_factory = tpl_observer_get_channel_factory (self);
-
-  /* Parallelize TplChannel preparations, when the last one will be ready, the
-   * counter will be 0 and tp_svc_client_observer_return_from_observe_channels
-   * can be called */
-  observing_ctx = g_slice_new0 (ObservingContext);
-  observing_ctx->self = TPL_OBSERVER (self);
-  observing_ctx->chan_n = g_list_length (channels);
-  observing_ctx->ctx = g_object_ref (context);
-
   for (l = channels; l != NULL; l = g_list_next (l))
-    {
-      TpChannel *channel = l->data;
-      TplChannel *tpl_chan;
-      GHashTable *prop_map;
-      const gchar *path;
+    _tpl_observer_register_channel (self, l->data);
 
-      path = tp_proxy_get_object_path (channel);
-
-      /* Ignore channel if we are already observing it */
-      if (g_hash_table_lookup (self->priv->channels, path) != NULL ||
-          g_hash_table_lookup (self->priv->preparing_channels, path) != NULL)
-        {
-          observing_ctx->chan_n--;
-          continue;
-        }
-
-      /* d.bus.propertyName.str/gvalue hash */
-      prop_map = tp_channel_borrow_immutable_properties (channel);
-      chan_type = tp_channel_get_channel_type (channel);
-
-      tpl_chan = chan_factory (chan_type, connection, path, prop_map, account,
-          &error);
-      if (tpl_chan == NULL)
-        {
-          DEBUG ("%s: %s", path, error->message);
-          g_clear_error (&error);
-          observing_ctx->chan_n--;
-          continue;
-        }
-      PATH_DEBUG (tpl_chan, "Starting preparation for TplChannel instance %p",
-          tpl_chan);
-
-      /* Pass the reference on the TplChannel to the hash table */
-      g_hash_table_insert (self->priv->preparing_channels,
-          (gchar *) tp_proxy_get_object_path (tpl_chan), tpl_chan);
-
-      _tpl_channel_prepare_async (tpl_chan, channel_prepared_cb,
-          observing_ctx);
-    }
-
-  /* Arguably we shouldn't claim to have accepted the channels if an error
-   * occurred above? */
-  if (!observing_context_try_to_return (observing_ctx))
-    tp_observe_channels_context_delay (context);
-}
-
-static gboolean
-observing_context_try_to_return (ObservingContext *observing_ctx)
-{
-  if (observing_ctx->chan_n == 0)
-    {
-      DEBUG ("Returning from observe channels");
-      tp_observe_channels_context_accept (observing_ctx->ctx);
-      g_object_unref (observing_ctx->ctx);
-      g_slice_free (ObservingContext, observing_ctx);
-      return TRUE;
-    }
-  else
-    {
-      return FALSE;
-    }
+  tp_observe_channels_context_accept (context);
 }
 
 static gboolean
 _tpl_observer_register_channel (TplObserver *self,
-    TplChannel *channel)
+    TpChannel *channel)
 {
   gchar *key;
 
   g_return_val_if_fail (TPL_IS_OBSERVER (self), FALSE);
-  g_return_val_if_fail (TPL_IS_CHANNEL (channel), FALSE);
+  g_return_val_if_fail (TP_IS_CHANNEL (channel), FALSE);
 
   key = (char *) tp_proxy_get_object_path (G_OBJECT (channel));
 
@@ -228,33 +142,6 @@ _tpl_observer_register_channel (TplObserver *self,
 }
 
 
-static void
-channel_prepared_cb (GObject *obj,
-    GAsyncResult *result,
-    gpointer user_data)
-{
-  ObservingContext *observing_ctx = user_data;
-  GError *error = NULL;
-
-  if (_tpl_action_chain_new_finish (obj, result, &error))
-    {
-      PATH_DEBUG (obj, "channel prepared");
-      _tpl_observer_register_channel (observing_ctx->self, TPL_CHANNEL (obj));
-    }
-  else
-    {
-      PATH_DEBUG (obj, "failed to prepare channel: %s", error->message);
-      g_error_free (error);
-    }
-
-  g_hash_table_remove (observing_ctx->self->priv->preparing_channels,
-      tp_proxy_get_object_path (obj));
-
-  observing_ctx->chan_n -= 1;
-  observing_context_try_to_return (observing_ctx);
-}
-
-
 static void
 tpl_observer_get_property (GObject *object,
     guint property_id,
@@ -279,7 +166,7 @@ tpl_observer_get_property (GObject *object,
 
           g_value_set_boxed (value, array);
 
-          g_ptr_array_free (array, TRUE);
+          g_ptr_array_unref (array);
           g_list_free (keys);
 
           break;
@@ -332,9 +219,6 @@ _tpl_observer_init (TplObserver *self)
   priv->channels = g_hash_table_new_full (g_str_hash, g_str_equal,
       NULL, g_object_unref);
 
-  priv->preparing_channels = g_hash_table_new_full (g_str_hash, g_str_equal,
-      NULL, g_object_unref);
-
   priv->logmanager = tpl_log_manager_dup_singleton ();
 
   /* Observe contact text channels */
@@ -355,21 +239,11 @@ _tpl_observer_init (TplObserver *self)
            TP_HANDLE_TYPE_ROOM,
       NULL));
 
-#ifdef ENABLE_CALL
-  /* Observe contact stream media channels */
-  tp_base_client_take_observer_filter (TP_BASE_CLIENT (self),
-      tp_asv_new (
-       TP_PROP_CHANNEL_CHANNEL_TYPE, G_TYPE_STRING,
-           TP_IFACE_CHANNEL_TYPE_STREAMED_MEDIA,
-       TP_PROP_CHANNEL_TARGET_HANDLE_TYPE, G_TYPE_UINT,
-           TP_HANDLE_TYPE_CONTACT,
-      NULL));
-
   /* Observe contact call channels */
   tp_base_client_take_observer_filter (TP_BASE_CLIENT (self),
       tp_asv_new (
        TP_PROP_CHANNEL_CHANNEL_TYPE, G_TYPE_STRING,
-           "org.freedesktop.Telepathy.Channel.Type.Call.DRAFT",
+           "org.freedesktop.Telepathy.Channel.Type.Call1",
        TP_PROP_CHANNEL_TARGET_HANDLE_TYPE, G_TYPE_UINT,
            TP_HANDLE_TYPE_CONTACT,
       NULL));
@@ -378,11 +252,10 @@ _tpl_observer_init (TplObserver *self)
   tp_base_client_take_observer_filter (TP_BASE_CLIENT (self),
       tp_asv_new (
        TP_PROP_CHANNEL_CHANNEL_TYPE, G_TYPE_STRING,
-           "org.freedesktop.Telepathy.Channel.Type.Call.DRAFT",
+           "org.freedesktop.Telepathy.Channel.Type.Call1",
        TP_PROP_CHANNEL_TARGET_HANDLE_TYPE, G_TYPE_UINT,
            TP_HANDLE_TYPE_ROOM,
       NULL));
-#endif /* ENABLE_CALL */
 
   tp_base_client_set_observer_recover (TP_BASE_CLIENT (self), TRUE);
 }
@@ -394,13 +267,7 @@ tpl_observer_dispose (GObject *obj)
   TplObserverPriv *priv = TPL_OBSERVER (obj)->priv;
 
   tp_clear_pointer (&priv->channels, g_hash_table_unref);
-  tp_clear_pointer (&priv->preparing_channels, g_hash_table_unref);
-
-  if (priv->logmanager != NULL)
-    {
-      g_object_unref (priv->logmanager);
-      priv->logmanager = NULL;
-    }
+  g_clear_object (&priv->logmanager);
 
   G_OBJECT_CLASS (_tpl_observer_parent_class)->dispose (obj);
 }
@@ -422,11 +289,12 @@ _tpl_observer_dup (GError **error)
           return NULL;
         }
 
-      factory = (TpSimpleClientFactory *) tp_automatic_client_factory_new (dbus);
+      factory = _tpl_client_factory_new (dbus);
 
       /* Pre-select feature to be initialized. */
       tp_simple_client_factory_add_contact_features_varargs (factory,
           TP_CONTACT_FEATURE_ALIAS,
+          TP_CONTACT_FEATURE_PRESENCE,
           TP_CONTACT_FEATURE_AVATAR_TOKEN,
           TP_CONTACT_FEATURE_INVALID);
 
@@ -470,13 +338,13 @@ _tpl_observer_dup (GError **error)
  */
 gboolean
 _tpl_observer_unregister_channel (TplObserver *self,
-    TplChannel *channel)
+    TpChannel *channel)
 {
   gboolean retval;
   gchar *key;
 
   g_return_val_if_fail (TPL_IS_OBSERVER (self), FALSE);
-  g_return_val_if_fail (TPL_IS_CHANNEL (channel), FALSE);
+  g_return_val_if_fail (TP_IS_CHANNEL (channel), FALSE);
 
   key = (char *) tp_proxy_get_object_path (TP_PROXY (channel));
 
@@ -493,24 +361,3 @@ _tpl_observer_unregister_channel (TplObserver *self,
 
   return retval;
 }
-
-
-static TplChannelFactory
-tpl_observer_get_channel_factory (TplObserver *self)
-{
-  g_return_val_if_fail (TPL_IS_OBSERVER (self), NULL);
-
-  return self->priv->channel_factory;
-}
-
-
-void
-_tpl_observer_set_channel_factory (TplObserver *self,
-    TplChannelFactory factory)
-{
-  g_return_if_fail (TPL_IS_OBSERVER (self));
-  g_return_if_fail (factory != NULL);
-  g_return_if_fail (self->priv->channel_factory == NULL);
-
-  self->priv->channel_factory = factory;
-}
