@@ -1,19 +1,5 @@
-#include <telepathy-logger/channel-factory-internal.h>
 #include <telepathy-logger/observer-internal.h>
 
-static gint factory_counter = 0;
-
-static TplChannel *
-mock_factory (const gchar *chan_type,
-    TpConnection *conn, const gchar *object_path, GHashTable *tp_chan_props,
-    TpAccount *tp_acc, GError **error)
-{
-  factory_counter += 1;
-  return NULL;
-}
-
-
-
 int
 main (int argc, char **argv)
 {
@@ -36,9 +22,8 @@ main (int argc, char **argv)
   /* it points to the same mem area, it should be still valid */
   g_assert (TPL_IS_OBSERVER (obs2));
 
-  /* register a ChanFactory and test ObserveChannel() */
-  _tpl_observer_set_channel_factory (obs, mock_factory);
 
+  /* FIXME: This test does not actually test anything useful */
 
   /* proper disposal for the singleton when no references are present */
   g_object_unref (obs);
